==> ark_4.8.2.orig.tar.xz: ark-4.8.2/plugins/cli7zplugin/kerfuffle_cli7z.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=Kerfuffle/Plugin
X-KDE-Library=kerfuffle_cli7z
X-KDE-PluginInfo-Author=Harald Hvaal
X-KDE-PluginInfo-Email=haraldhv@stud.ntnu.no
X-KDE-PluginInfo-Name=kerfuffle_7z
X-KDE-PluginInfo-Version=0.0.1
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-License=GPLv2+
X-KDE-Priority=120
X-KDE-Kerfuffle-APIRevision=1
X-KDE-Kerfuffle-ReadWrite=true
Name=7zip archive plugin
Name[ar]=ملحق أرشيف 7zip
Name[ast]=Complementu d'archivu comprimíu 7zip
Name[bs]=Priključak 7z arhiva
Name[ca]=Connector per arxius 7zip
Name[ca@valencia]=Connector per arxius 7zip
Name[cs]=Modul pro archiv 7zip
Name[da]=Plugin til 7zip-arkiver
Name[de]=7zip-Archiv-Modul
Name[el]=Πρόσθετο αρχειοθήκης 7zip
Name[en_GB]=7zip archive plugin
Name[es]=Complemento de archivo comprimido 7zip
Name[et]=7zip arhiivi plugin
Name[eu]=7zip artxibuen plugina
Name[fi]=7zip-arkistointiliitännäinen
Name[fr]=Module pour archive 7zip
Name[ga]=Breiseán cartlainne 7zip
Name[gl]=Extensión de arquivo de 7zip
Name[hr]=Arhivni priključak 7zip
Name[hu]=7zip modul
Name[ia]=Plugin de archivar 7zip
Name[id]=Pengaya arsip 7zip
Name[it]=plugin archivio 7zip
Name[ja]=7zip アーカイブ用プラグイン
Name[kk]=7zip архив плагині
Name[km]=កម្មវិធី​ជំនួយ​ប័ណ្ណសារ 7zip
Name[ko]=7zip 압축 플러그인
Name[lt]=7zip archyvo priedas
Name[lv]=7zip arhīvu spraudnis
Name[nb]=Programtillegg for 7zip-arkiv
Name[nds]=7zip-Archievmoduul
Name[nl]=7zip-archiefplug-in
Name[nn]=7zip-arkivtillegg
Name[pa]=7zip ਅਕਾਇਵ ਪਲੱਗਇਨ
Name[pl]=Wtyczka archiwów 7zip
Name[pt]='Plugin' de pacotes '7zip'
Name[pt_BR]=Plug-in de arquivos 7zip
Name[ro]=Modul de arhivă 7zip
Name[ru]=Поддержка архивов 7zip
Name[sk]=Modul 7zip archívu
Name[sl]=Vstavek za arhive 7zip
Name[sq]=7zip arkiv plugin
Name[sr]=Прикључак 7з архива
Name[sr@ijekavian]=Прикључак 7з архива
Name[sr@ijekavianlatin]=Priključak 7z arhiva
Name[sr@latin]=Priključak 7z arhiva
Name[sv]=Insticksprogram för 7zip arkiv
Name[th]=ส่วนเสริมการจัดการแฟ้มจัดเก็บแบบ 7zip
Name[tr]=7zip arşivi eklentisi
Name[uk]=Додаток для архівів 7zip
Name[x-test]=xx7zip archive pluginxx
Name[zh_CN]=7zip 归档插件
Name[zh_TW]=7zip 壓縮檔外掛程式
MimeType=@SUPPORTED_CLI7Z_MIMETYPES@

==> ark-4.8.90.tar.xz: ark-4.8.90/plugins/cli7zplugin/kerfuffle_cli7z.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=Kerfuffle/Plugin
X-KDE-Library=kerfuffle_cli7z
X-KDE-PluginInfo-Author=Harald Hvaal
X-KDE-PluginInfo-Email=haraldhv@stud.ntnu.no
X-KDE-PluginInfo-Name=kerfuffle_7z
X-KDE-PluginInfo-Version=0.0.1
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-License=GPLv2+
X-KDE-Priority=120
X-KDE-Kerfuffle-APIRevision=1
X-KDE-Kerfuffle-ReadWrite=true
Name=7zip archive plugin
Name[ar]=ملحق أرشيف 7zip
Name[ast]=Complementu d'archivu comprimíu 7zip
Name[bs]=Priključak 7z arhiva
Name[ca]=Connector per arxius 7zip
Name[ca@valencia]=Connector per arxius 7zip
Name[cs]=Modul pro archiv 7zip
Name[da]=Plugin til 7zip-arkiver
Name[de]=7zip-Archiv-Modul
Name[el]=Πρόσθετο αρχειοθήκης 7zip
Name[en_GB]=7zip archive plugin
Name[es]=Complemento de archivo comprimido 7zip
Name[et]=7zip arhiivi plugin
Name[eu]=7zip artxibuen plugina
Name[fi]=7zip-arkistointiliitännäinen
Name[fr]=Module pour archive 7zip
Name[ga]=Breiseán cartlainne 7zip
Name[gl]=Extensión de arquivo de 7zip
Name[hr]=Arhivni priključak 7zip
Name[hu]=7zip modul
Name[ia]=Plugin de archivar 7zip
Name[id]=Pengaya arsip 7zip
Name[it]=plugin archivio 7zip
Name[ja]=7zip アーカイブ用プラグイン
Name[kk]=7zip архив плагині
Name[km]=កម្មវិធី​ជំនួយ​ប័ណ្ណសារ 7zip
Name[ko]=7zip 압축 플러그인
Name[lt]=7zip archyvo priedas
Name[lv]=7zip arhīvu spraudnis
Name[nb]=Programtillegg for 7zip-arkiv
Name[nds]=7zip-Archievmoduul
Name[nl]=7zip-archiefplug-in
Name[nn]=7zip-arkivtillegg
Name[pa]=7zip ਅਕਾਇਵ ਪਲੱਗਇਨ
Name[pl]=Wtyczka archiwów 7zip
Name[pt]='Plugin' de pacotes '7zip'
Name[pt_BR]=Plugin de arquivos 7zip
Name[ro]=Modul de arhivă 7zip
Name[ru]=Поддержка архивов 7zip
Name[sk]=Modul 7zip archívu
Name[sl]=Vstavek za arhive 7zip
Name[sq]=7zip arkiv plugin
Name[sr]=Прикључак 7з архива
Name[sr@ijekavian]=Прикључак 7з архива
Name[sr@ijekavianlatin]=Priključak 7z arhiva
Name[sr@latin]=Priključak 7z arhiva
Name[sv]=Insticksprogram för 7zip arkiv
Name[th]=ส่วนเสริมการจัดการแฟ้มจัดเก็บแบบ 7zip
Name[tr]=7zip arşivi eklentisi
Name[uk]=Додаток для архівів 7zip
Name[x-test]=xx7zip archive pluginxx
Name[zh_CN]=7zip 归档插件
Name[zh_TW]=7zip 壓縮檔外掛程式
MimeType=@SUPPORTED_CLI7Z_MIMETYPES@
